import { DeepClient, SerialOperation } from '@deep-foundation/deeplinks/imports/client.js';
/**
  * Gets serial operations to insert {@link Package.Notify}
  *
  * @example
  * #### Insert {@link Package.Notify}
 ```ts
 const {serialOperations, linkIds} = await getNotifyInsertSerialOperations({
   deep
 });
 await deep.serial({
   operations: serialOperations
 })
 ```
   * #### Insert {@link Package.Notify} with reserved link id
  ```ts
  const reservedLinkIds = await deep.reserve(2);
  const notifyLinkId = reservedLinkIds.pop();
  const containLinkId = reservedLinkIds.pop();
  
  const {serialOperations, linkIds} = await getNotifyInsertSerialOperations({
    deep,
    notify: {
      title,
      body,
    },
    reservedLinkIds: {
      notifyLinkId,
      containLinkId,
    }
  });
  await deep.serial({
    operations: serialOperations
  })
  ```
  */
export declare function getNotifyInsertSerialOperations(param: GetNotifyInsertSerialOperationsParam): Promise<GetNotifyInsertSerialOperationsResult>;
export interface GetNotifyInsertSerialOperationsParam {
    /**
     * Reserved link ids that will be used in the serial operations
     */
    reservedLinkIds?: {
        /**
         * Reserved link id for the notify
         */
        notifyLinkId?: number;
        /**
         * Reserved link id for the contain
         */
        containLinkId?: number;
    };
    /**
     * Link ids of types that will be used in the serial operations
     */
    typeLinkIds?: {
        /**
         * Link id of the contain type
         */
        containTypeLinkId?: number;
        /**
         * Link id of the notify type
         */
        notifyTypeLinkId?: number;
    };
    /**
     * Deep Client
     */
    deep: DeepClient;
    /**
     * Link id of the container
     *
     * @remarks
     * If it is null, contain link will not be created
     * @defaultValue {@link GetNotifyInsertSerialOperationsParam.deep.linkId} if not provided or undefined
     */
    containerLinkId?: number | undefined | null;
    /**
     * Value of the contain link
     *
     * @remarks
     * If {@link GetNotifyInsertSerialOperationsParam.containerLinkId} is null, this will be ignored
     */
    containValue?: string | undefined;
    /**
     * Link id of the push notification
     */
    pushNotificationLinkId: number;
    /**
     * Link id of the device
     */
    deviceLinkId: number;
}
export interface GetNotifyInsertSerialOperationsResult {
    serialOperations: Array<SerialOperation>;
    linkIds: Required<Exclude<GetNotifyInsertSerialOperationsParam['reservedLinkIds'], undefined>>;
}
